@@ -23,11 +23,11 @@ import pytest
         ("Cambiatuscromos", "0.1.1alpha", ".linux-x86_64.exe")),
     ("Aesthete-0.4.2.win32.exe", ("Aesthete", "0.4.2", ".win32.exe")),
     ("DTL-1.0.5.win-amd64.exe", ("DTL", "1.0.5", ".win-amd64.exe")),
-    ("Cheetah-2.2.2-1.x86_64.rpm", ("Cheetah", "2.2.2-1", ".x86_64.rpm")),
-    ("Cheetah-2.2.2-1.src.rpm", ("Cheetah", "2.2.2-1", ".src.rpm")),
-    ("Cheetah-2.2.2-1.x85.rpm", ("Cheetah", "2.2.2-1", ".x85.rpm")),
-    ("Cheetah-2.2.2.dev1.x85.rpm", ("Cheetah", "2.2.2.dev1", ".x85.rpm")),
-    ("Cheetah-2.2.2.dev1.noarch.rpm", ("Cheetah", "2.2.2.dev1", ".noarch.rpm")),
+    ("Cheetah-2.2.2-1.x86_64.rpm", ("Cheetah", "2.2.2", "-1.x86_64.rpm")),
+    ("Cheetah-2.2.2-1.src.rpm", ("Cheetah", "2.2.2", "-1.src.rpm")),
+    ("Cheetah-2.2.2-1.x85.rpm", ("Cheetah", "2.2.2", "-1.x85.rpm")),
+    ("Cheetah-2.2.2.dev1-1.x85.rpm", ("Cheetah", "2.2.2.dev1", "-1.x85.rpm")),
+    ("Cheetah-2.2.2.dev1-1.noarch.rpm", ("Cheetah", "2.2.2.dev1", "-1.noarch.rpm")),
     ("deferargs.tar.gz", ("deferargs", "", ".tar.gz")),
     ("hello-1.0.doc.zip", ("hello", "1.0", ".doc.zip")),
     ("Twisted-12.0.0.win32-py2.7.msi",
@@ -42,6 +42,7 @@ def test_splitbasename(releasename, expected):
     result = splitbasename(releasename)
     assert result == expected
 
+
 @pytest.mark.parametrize(("releasename", "expected"), [
     ("x-2.3.zip", ("source", "sdist")),
     ("x-2.3-0.4.0.win32-py3.1.exe", ("3.1", "bdist_wininst")),
@@ -58,6 +59,7 @@ def test_get_pyversion_filetype(releasename, expected):
     result = get_pyversion_filetype(releasename)
     assert result == expected
 
+
 @pytest.mark.parametrize(("releasename", "expected"), [
     ("pytest-2.3.4.zip", ("pytest-2.3.4", ".zip")),
     ("green-0.4.0-py2.5-win32.egg", ("green-0.4.0-py2.5-win32", ".egg")),
@@ -103,6 +105,7 @@ def test_version():
     ver2 = Version("1.1")
     assert max([ver1, ver2]) == ver2
 
+
 class TestBasenameMeta:
     def test_doczip(self):
         meta1 = BasenameMeta("x-1.0.doc.zip")
@@ -161,5 +164,3 @@ def test_parse_requirement():
     assert req.project_name == "hello"
     assert "1.0" in req
     assert "0.9" not in req
-
--1.0
